;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "bufferfile" "20251011.1158"
  "Rename/Delete/Copy Files and Associated Buffers."
  '((emacs "26.1"))
  :url "https://github.com/jamescherti/bufferfile.el"
  :commit "e4e5c46fcf656fa06f7388b514fbf17636bba424"
  :revdesc "e4e5c46fcf65"
  :keywords '("convenience"))
